@@ -2,7 +2,7 @@ import logging
 
 from .views import IndexView
 from filters import TemplateFilters
-from flask import Blueprint
+from flask import Blueprint, url_for
 from flask.ext.babelpkg import gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
 from flask.ext.appbuilder import translations
@@ -156,7 +156,7 @@ class BaseApp(object):
             :param baseview:
                 A BaseView type class instantiated.
             :param name:
-                The string name that will be displayed on the menu.
+                The string name that identifies the menu.
             :param href:
                 Override the generated href for the menu. if non provided default_view from view will be set as href.
             :param icon:
@@ -167,7 +167,9 @@ class BaseApp(object):
                 The menu category where the menu will be included, if non provided the view will be acessible as a top menu.
             :param category_icon:
                 Font-Awesome icon name for the category, optional.
-            
+            :param category_label:
+                The label that will be displayed on the menu, if absent param name will be used
+
             Examples::
             
                 baseapp = BaseApp(app, db)
@@ -175,7 +177,7 @@ class BaseApp(object):
                 baseapp.add_view(MyGeneralView(), "My View")
                 # Register a view, a submenu "Other View" from "Other" with a phone icon.
                 baseapp.add_view(MyOtherGeneralView(), "Other View", icon='fa-phone', category="Others")
-                $ Regiter a view, with category icon and translation.
+                # Register a view, with category icon and translation.
                 baseapp.add_view(YetOtherGeneralView(), "Other View", icon='fa-phone',
                                 label=_('Other View'), category="Others", category_icon='fa-envelop',
                                 category_label=_('Other View'))
@@ -198,7 +200,7 @@ class BaseApp(object):
             Add your own links to menu using this method
             
             :param name:
-                The string name that will be displayed on the menu.
+                The string name that identifies the menu.
             :param href:
                 Override the generated href for the menu.
             :param icon:
@@ -209,6 +211,9 @@ class BaseApp(object):
                 The menu category where the menu will be included, if non provided the view will be acessible as a top menu.
             :param category_icon:
                 Font-Awesome icon name for the category, optional.
+            :param category_label:
+                The label that will be displayed on the menu, if absent param name will be used
+
         """
         self.menu.add_link(name=name, href=href, icon=icon, label=label,
                            category=category, category_icon=category_icon,
@@ -241,6 +246,26 @@ class BaseApp(object):
             self.register_blueprint(baseview, endpoint=endpoint, static_folder=static_folder)
             self._add_permission(baseview)
 
+    @property
+    def get_url_for_login(self):
+        return url_for('%s.%s' % (self.sm.auth_view.endpoint, 'login'))
+
+    @property
+    def get_url_for_logout(self):
+        return url_for('%s.%s' % (self.sm.auth_view.endpoint, 'logout'))
+
+    @property
+    def get_url_for_index(self):
+        return url_for('%s.%s' % (self.indexview.endpoint, self.indexview.default_view))
+
+    @property
+    def get_url_for_userinfo(self):
+        return url_for('%s.%s' % (self.sm.user_view.endpoint, 'userinfo'))
+
+    def get_url_for_locale(self, lang):
+        return url_for('%s.%s' % (self.bm.locale_view.endpoint, self.bm.locale_view.default_view), locale= lang)
+
+
     def _add_permission(self, baseview):
         try:
             self.sm.add_permissions_view(baseview.base_permissions, baseview.__class__.__name__)
