@@ -188,6 +188,9 @@ class BaseModelView(BaseView):
             class MyView(GeneralView):
                 datamodel = SQLAModel(MyTable, db.session)
     """
+
+    title = 'Title'
+
     search_columns = None
     """ 
         List with allowed search columns, if not provided all possible search columns will be used 
@@ -250,6 +253,8 @@ class BaseModelView(BaseView):
         self._base_model_init_forms()
         super(BaseModelView, self).__init__(**kwargs)
 
+    def _init_titles(self):
+        pass
 
     def _base_model_init_vars(self):
         self.label_columns = self.label_columns or {}
@@ -459,6 +464,7 @@ class BaseCRUDView(BaseModelView):
             self.edit_title = 'Edit ' + self._prettify_name(self.datamodel.obj.__name__)
         if not self.show_title:
             self.show_title = 'Show ' + self._prettify_name(self.datamodel.obj.__name__)
+        self.title = self.list_title
 
     def _init_properties(self):
         self.related_views = self.related_views or []
@@ -500,35 +506,44 @@ class BaseCRUDView(BaseModelView):
     -----------------------------------------------------        
     """
 
-    def _get_related_list_widget(self, item, related_view,
+    def _get_related_view_widget(self, item, related_view,
                                  order_column='', order_direction='',
                                  page=None, page_size=None):
 
         fk = related_view.datamodel.get_related_fk(self.datamodel.obj)
         filters = Filters().add_filter_related_view(fk, FilterRelationOneToManyEqual,
                                                     related_view.datamodel, self.datamodel.get_pk_value(item))
-        return related_view._get_list_widget(filters=filters,
+        return related_view._get_view_widget(filters=filters,
                                              order_column=order_column,
                                              order_direction=order_direction,
                                              page=page, page_size=page_size)
 
-    def _get_related_list_widgets(self, item, orders=None,
-                                  pages=None, page_sizes=None,
-                                  widgets=None, **args):
+
+    def _get_related_views_widgets(self, item, orders=None,
+                                   pages=None, page_sizes=None,
+                                   widgets=None, **args):
         widgets = widgets or {}
-        widgets['related_lists'] = []
+        widgets['related_views'] = []
         for view in self._related_views:
             if orders.get(view.__class__.__name__):
                 order_column, order_direction = orders.get(view.__class__.__name__)
             else:
                 order_column, order_direction = '', ''
-            widgets['related_lists'].append(self._get_related_list_widget(item, view,
+            widgets['related_views'].append(self._get_related_view_widget(item, view,
                                                                           order_column, order_direction,
                                                                           page=pages.get(view.__class__.__name__),
                                                                           page_size=page_sizes.get(
-                                                                              view.__class__.__name__)).get('list'))
+                                                                              view.__class__.__name__)))
         return widgets
 
+    def _get_view_widget(self, **kwargs):
+        """
+            :return:
+                Returns a widget
+        """
+        log.info("KWARGS {0}".format(kwargs))
+        return self._get_list_widget(**kwargs).get('list')
+
     def _get_list_widget(self, filters,
                          actions=None,
                          order_column='',
@@ -639,8 +654,8 @@ class BaseCRUDView(BaseModelView):
         widgets = self._get_show_widget(pk)
         item = self.datamodel.get(pk)
 
-        return self._get_related_list_widgets(item, orders=orders,
-                                              pages=pages, page_sizes=page_sizes, widgets=widgets)
+        return self._get_related_views_widgets(item, orders=orders,
+                                               pages=pages, page_sizes=page_sizes, widgets=widgets)
 
 
     def _add(self):
@@ -696,8 +711,8 @@ class BaseCRUDView(BaseModelView):
             form = self.edit_form(obj=item)
             form = form.refresh(obj=item)
         widgets = self._get_edit_widget(form=form, exclude_cols=exclude_cols)
-        widgets = self._get_related_list_widgets(item, filters={},
-                                                 orders=orders, pages=pages, page_sizes=page_sizes, widgets=widgets)
+        widgets = self._get_related_views_widgets(item, filters={},
+                                                  orders=orders, pages=pages, page_sizes=page_sizes, widgets=widgets)
         return widgets
 
 
