@@ -5,6 +5,7 @@ from flask.ext.babelpkg import lazy_gettext
 from widgets import ChartWidget, DirectChartWidget, MultipleChartWidget
 from ..widgets import SearchWidget
 from ..security.decorators import has_access
+from ..models.filters import Filters, FilterRelationOneToManyEqual
 from ..baseviews import BaseModelView, expose
 from ..urltools import *
 
@@ -27,6 +28,8 @@ class BaseChartView(BaseModelView):
 
     chart_title = 'Chart'
     """ A title to be displayed on the chart """
+    title = 'Title'
+
     group_by_label = lazy_gettext('Group by')
     """ The label that is displayed for the chart selection """
 
@@ -44,14 +47,24 @@ class BaseChartView(BaseModelView):
     """ New for 0.6.4, on test, don't use yet """
 
 
-    def _get_chart_widget(self, value_columns=None, widgets=None, **args):
-        widgets = widgets or dict()
-        widgets['chart'] = self.chart_widget(route_base=self.route_base,
-                                             chart_title=self.chart_title,
-                                             chart_type=self.chart_type,
-                                             chart_3d=self.chart_3d,
-                                             value_columns=value_columns, **args)
-        return widgets
+    def __init__(self, **kwargs):
+        self._init_titles()
+        super(BaseModelView, self).__init__(**kwargs)
+
+
+    def _init_titles(self):
+        self.title = self.chart_title
+
+    def _get_chart_widget(self, filters=None,
+                          widgets=None, **args):
+        pass
+
+    def _get_view_widget(self, **kwargs):
+        """
+            :return:
+                Returns a widget
+        """
+        return self._get_chart_widget(**kwargs).get('chart')
 
 
 class BaseSimpleGroupByChartView(BaseChartView):
@@ -64,6 +77,28 @@ class BaseSimpleGroupByChartView(BaseChartView):
         else:
             super(BaseChartView, self).__init__(**kwargs)
 
+    def _get_chart_widget(self, filters=None,
+                          order_column='',
+                          order_direction='',
+                          widgets=None,
+                          group_by=None,
+                          height=None,
+                          **args):
+
+        height = height or self.height
+        widgets = widgets or dict()
+        group_by = group_by or self.group_by_columns[0]
+        joined_filters = filters.get_joined_filters(self._base_filters)
+        value_columns = self.datamodel.query_simple_group(group_by, filters=joined_filters)
+
+        widgets['chart'] = self.chart_widget(route_base=self.route_base,
+                                             chart_title=self.chart_title,
+                                             chart_type=self.chart_type,
+                                             chart_3d=self.chart_3d,
+                                             height=height,
+                                             value_columns=value_columns, **args)
+        return widgets
+
 
 class BaseSimpleDirectChartView(BaseChartView):
     direct_columns = []
@@ -88,6 +123,32 @@ class BaseSimpleDirectChartView(BaseChartView):
         return self.direct_columns.keys()
 
 
+    def _get_chart_widget(self, filters=None,
+                          order_column='',
+                          order_direction='',
+                          widgets=None,
+                          direct=None,
+                          height=None,
+                          **args):
+
+        height = height or self.height
+        widgets = widgets or dict()
+        joined_filters = filters.get_joined_filters(self._base_filters)
+        count, lst = self.datamodel.query(filters=joined_filters,
+                                          order_column=order_column,
+                                          order_direction=order_direction)
+        value_columns = self.datamodel.get_values(lst, list(direct))
+        value_columns = jsontools.dict_to_json(direct[0], direct[1:], self.label_columns, value_columns)
+
+        widgets['chart'] = self.chart_widget(route_base=self.route_base,
+                                             chart_title=self.chart_title,
+                                             chart_type=self.chart_type,
+                                             chart_3d=self.chart_3d,
+                                             height=height,
+                                             value_columns=value_columns, **args)
+        return widgets
+
+
 class ChartView(BaseSimpleGroupByChartView):
     """
         Provides a simple (and hopefully nice) way to draw charts on your application.
@@ -103,9 +164,8 @@ class ChartView(BaseSimpleGroupByChartView):
         get_filter_args(self._filters)
 
         group_by = group_by or self.group_by_columns[0]
-        value_columns = self.datamodel.query_simple_group(group_by, filters=self._filters)
 
-        widgets = self._get_chart_widget(value_columns=value_columns)
+        widgets = self._get_chart_widget(filters=self._filters, group_by=group_by)
         widgets = self._get_search_widget(form=form, widgets=widgets)
         return render_template(self.chart_template, route_base=self.route_base,
                                title=self.chart_title,
@@ -127,6 +187,35 @@ class TimeChartView(BaseSimpleGroupByChartView):
     chart_template = 'appbuilder/general/charts/chart_time.html'
     chart_type = 'ColumnChart'
 
+
+    def _get_chart_widget(self, filters=None,
+                          order_column='',
+                          order_direction='',
+                          widgets=None,
+                          group_by=None,
+                          period=None,
+                          height=None,
+                          **args):
+
+        height = height or self.height
+        widgets = widgets or dict()
+        group_by = group_by or self.group_by_columns[0]
+        joined_filters = filters.get_joined_filters(self._base_filters)
+
+        if period == 'month' or not period:
+            value_columns = self.datamodel.query_month_group(group_by, filters=joined_filters)
+        elif period == 'year':
+            value_columns = self.datamodel.query_year_group(group_by, filters=joined_filters)
+
+        widgets['chart'] = self.chart_widget(route_base=self.route_base,
+                                             chart_title=self.chart_title,
+                                             chart_type=self.chart_type,
+                                             chart_3d=self.chart_3d,
+                                             height=height,
+                                             value_columns=value_columns, **args)
+        return widgets
+
+
     @expose('/chart/<group_by>/<period>')
     @expose('/chart/')
     @has_access
@@ -136,18 +225,17 @@ class TimeChartView(BaseSimpleGroupByChartView):
 
         group_by = group_by or self.group_by_columns[0]
 
-        if period == 'month' or not period:
-            value_columns = self.datamodel.query_month_group(group_by, filters=self._filters)
-        elif period == 'year':
-            value_columns = self.datamodel.query_year_group(group_by, filters=self._filters)
-        widgets = self._get_chart_widget(value_columns=value_columns)
+        widgets = self._get_chart_widget(filters=self._filters,
+                                         group_by=group_by,
+                                         period=period,
+                                         height=self.height)
+
         widgets = self._get_search_widget(form=form, widgets=widgets)
         return render_template(self.chart_template, route_base=self.route_base,
                                title=self.chart_title,
                                label_columns=self.label_columns,
                                group_by_columns=self.group_by_columns,
                                group_by_label=self.group_by_label,
-                               height=self.height,
                                widgets=widgets,
                                baseapp=self.baseapp)
 
@@ -183,13 +271,11 @@ class DirectChartView(BaseSimpleDirectChartView):
             order_column, order_direction = self.base_order
         else:
             order_column, order_direction = '', ''
-        count, lst = self.datamodel.query(filters=self._filters,
-                                          order_column=order_column,
-                                          order_direction=order_direction)
-        value_columns = self.datamodel.get_values(lst, list(direct))
-        value_columns = jsontools.dict_to_json(direct[0], direct[1:], self.label_columns, value_columns)
 
-        widgets = self._get_chart_widget(value_columns=value_columns)
+        widgets = self._get_chart_widget(filters=self._filters,
+                                         order_column=order_column,
+                                         order_direction=order_direction,
+                                         direct=direct)
         widgets = self._get_search_widget(form=form, widgets=widgets)
         return render_template(self.chart_template, route_base=self.route_base,
                                title=self.chart_title,
