@@ -2,20 +2,22 @@ from flask import url_for
 
 
 class MenuItem(object):
-
     name = ""
-    baseview = None
     href = ""
     icon = ""
+    label = ""
+    baseview = None
     childs = []
 
-    def __init__(self, name, href="", icon="", childs=[], baseview = None):
+    def __init__(self, name, href="", icon="", label="", childs=[], baseview=None):
         self.name = name
         self.href = href
         self.icon = icon
-        if (self.childs):
+        self.label = label
+        if self.childs:
             self.childs = childs
-        else: self.childs = []
+        else:
+            self.childs = []
         self.baseview = baseview
 
     def get_url(self):
@@ -30,11 +32,11 @@ class MenuItem(object):
     def __repr__(self):
         return self.name
 
-class Menu(object):
 
+class Menu(object):
     menu = None
     reverse = True
-    
+
     def __init__(self, reverse=True):
         self.menu = []
         self.reverse = reverse
@@ -53,25 +55,30 @@ class Menu(object):
                         return j
 
 
-    def add_category(self, category, icon="", parent_category=""):
+    def add_category(self, category, icon="", label="", parent_category=""):
+        label = label or category
         if parent_category == "":
-            self.menu.append(MenuItem(name=category, icon = icon))
+            self.menu.append(MenuItem(name=category, icon=icon, label=label))
         else:
-            self.find_category(category).childs.append(MenuItem(name=category, icon = icon))
-        
+            self.find_category(category).childs.append(MenuItem(name=category, icon=icon, label=label))
 
-    def add_link(self, name, href="", icon="", category="", baseview = None):
+
+    def add_link(self, name, href="", icon="", label="", category="", category_icon="", category_label="",
+                 baseview=None):
+        label = label or name
+        category_label = category_label or category
         if category == "":
-            self.menu.append(MenuItem(name=name, href=href, icon = icon, baseview=baseview))
+            self.menu.append(MenuItem(name=name, href=href, icon=icon, label=label, baseview=baseview))
         else:
             menu_item = self.find_category(category)
             if menu_item:
-                menu_item.childs.append(MenuItem(name=name, href=href, icon = icon, baseview = baseview))
+                menu_item.childs.append(MenuItem(name=name, href=href, icon=icon, label=label, baseview=baseview))
             else:
-                self.add_category(category=category)
-                self.find_category(category).childs.append(MenuItem(name=name, 
-                                        href=href, icon = icon, baseview = baseview))
-        
+                self.add_category(category=category, icon=category_icon, label=category_label)
+                self.find_category(category).childs.append(MenuItem(name=name,
+                                                                    href=href, icon=icon, label=label,
+                                                                    baseview=baseview))
+
 
     def add_separator(self, category=""):
         menu_item = self.find_category(category)
@@ -79,3 +86,4 @@ class Menu(object):
             menu_item.childs.append(MenuItem("-"))
         else:
             raise Exception("Menu separator does not have correct category {}".format(category))
+
