@@ -1,6 +1,13 @@
-from sqlalchemy import Table, Column, Integer, String, Boolean, ForeignKey
-from sqlalchemy.orm import relationship, column_property
+import datetime
+from flask import g
+from sqlalchemy import Table, Column, Integer, String, Boolean, DateTime, ForeignKey
+from sqlalchemy.orm import relationship, backref
+from sqlalchemy.ext.declarative import declared_attr
 from flask.ext.appbuilder import Base
+from .._compat import as_unicode
+
+
+_dont_audit = False
 
 
 class Permission(Base):
@@ -62,18 +69,46 @@ class User(Base):
     id = Column(Integer, primary_key=True)
     first_name = Column(String(64), nullable=False)
     last_name = Column(String(64), nullable=False)
-    full_name = column_property(first_name + " " + last_name)
     username = Column(String(32), unique=True, nullable=False)
-    password = Column(String(32))
+    password = Column(String(256))
     active = Column(Boolean)
-    email = Column(String(64), unique=True, nullable=True)
+    email = Column(String(64), unique=True, nullable=False)
 
-    #last_login = Column(DateTime, default=datetime.datetime.now, nullable=False)
-    #login_count = Column(Integer)
+    last_login = Column(DateTime)
+    login_count = Column(Integer)
+    fail_login_count = Column(Integer)
 
     role_id = Column(Integer, ForeignKey('ab_role.id'), nullable=False)
     role = relationship("Role")
 
+    created_on = Column(DateTime, default=datetime.datetime.now, nullable=True)
+
+    changed_on = Column(DateTime, default=datetime.datetime.now, nullable=True)
+
+    @declared_attr
+    def created_by_fk(self):
+        return Column(Integer, ForeignKey('ab_user.id'),
+                      default=self.get_user_id, nullable=True)
+
+    @declared_attr
+    def changed_by_fk(self):
+        return Column(Integer, ForeignKey('ab_user.id'),
+                      default=self.get_user_id, nullable=True)
+
+    created_by = relationship("User", backref=backref("created", uselist=True),
+                              remote_side=[id], primaryjoin='User.created_by_fk == User.id', uselist=False)
+    changed_by = relationship("User", backref=backref("changed", uselist=True),
+                              remote_side=[id], primaryjoin='User.changed_by_fk == User.id', uselist=False)
+
+
+    @classmethod
+    def get_user_id(cls):
+        try:
+            return g.user.id
+        except Exception as e:
+            return None
+
+
     @staticmethod
     def make_unique_nickname(nickname):
         if User.query.filter_by(nickname=nickname).first() is None:
@@ -99,11 +134,12 @@ class User(Base):
         return False
 
     def get_id(self):
-        return unicode(self.id)
+        return as_unicode(self.id)
 
     def get_full_name(self):
-        return self.first_name + " " + self.last_name
+        return u'{0} {1}'.format(self.first_name, self.last_name)
 
     def __repr__(self):
         return self.get_full_name()
 
+
